@@ -14,7 +14,7 @@ package MCE::Core::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '1.884';
+our $VERSION = '1.897';
 
 my $_tid = $INC{'threads.pm'} ? threads->tid() : 0;
 
@@ -260,7 +260,8 @@ no warnings qw( bareword threads recursion uninitialized );
          # inlined for performance
          $_dat_ex = sub {
             my $_pid = $_tid ? $$ .'.'. $_tid : $$;
-            MCE::Util::_sock_ready($_DAT_LOCK->{_r_sock}) if $_is_MSWin32;
+            CORE::lock($_DAT_LOCK->{_t_lock}), MCE::Util::_sock_ready($_DAT_LOCK->{_r_sock})
+               if $_is_MSWin32;
             MCE::Util::_sysread($_DAT_LOCK->{_r_sock}, my($b), 1), $_DAT_LOCK->{ $_pid } = 1
                unless $_DAT_LOCK->{ $_pid };
          };
@@ -737,7 +738,7 @@ MCE::Core::Worker - Core methods for the worker process
 
 =head1 VERSION
 
-This document describes MCE::Core::Worker version 1.884
+This document describes MCE::Core::Worker version 1.897
 
 =head1 DESCRIPTION
 
